@@ -2,6 +2,8 @@ pub mod ccgroup;
 pub mod cgroup;
 pub mod command;
 pub mod context_sw;
+pub mod voluntary_context_sw;
+pub mod involuntary_context_sw;
 pub mod cpu_time;
 #[cfg(feature = "docker")]
 pub mod docker;
@@ -81,6 +83,8 @@ pub use self::ccgroup::Ccgroup;
 pub use self::cgroup::Cgroup;
 pub use self::command::Command;
 pub use self::context_sw::ContextSw;
+pub use self::voluntary_context_sw::VoluntaryContextSw;
+pub use self::involuntary_context_sw::InvoluntaryContextSw;
 pub use self::cpu_time::CpuTime;
 #[cfg(feature = "docker")]
 pub use self::docker::Docker;
@@ -172,6 +176,8 @@ pub enum ConfigColumnKind {
     Cgroup,
     Command,
     ContextSw,
+    VoluntaryContextSw,
+    InvoluntaryContextSw,
     CpuTime,
     Docker,
     Eip,
@@ -266,6 +272,8 @@ pub fn gen_column(
         ConfigColumnKind::Cgroup => Box::new(Cgroup::new(header)),
         ConfigColumnKind::Command => Box::new(Command::new(header)),
         ConfigColumnKind::ContextSw => Box::new(ContextSw::new(header)),
+        ConfigColumnKind::VoluntaryContextSw => Box::new(VoluntaryContextSw::new(header)),
+        ConfigColumnKind::InvoluntaryContextSw => Box::new(InvoluntaryContextSw::new(header)),
         ConfigColumnKind::CpuTime => Box::new(CpuTime::new(header)),
         #[cfg(feature = "docker")]
         ConfigColumnKind::Docker => Box::new(Docker::new(header, _docker_path)),
@@ -366,6 +374,14 @@ pub static KIND_LIST: Lazy<BTreeMap<ConfigColumnKind, (&'static str, &'static st
                 ConfigColumnKind::ContextSw,
                 ("ContextSw", "Context switch count"),
             ),
+            (
+                ConfigColumnKind::VoluntaryContextSw,
+                ("VoluntaryContextSw", "Voluntary context switch count"),
+            ),
+            (
+                ConfigColumnKind::InvoluntaryContextSw,
+                ("InvoluntaryContextSw", "Involuntary context switch count"),
+            ),
             (
                 ConfigColumnKind::CpuTime,
                 ("CpuTime", "Cumulative CPU time"),
@@ -749,6 +765,14 @@ kind = "ContextSw"
 style = "BrightRed"
 align = "Right"
 [[columns]]
+kind = "VoluntaryContextSw"
+style = "BrightRed"
+align = "Right"
+[[columns]]
+kind = "InvoluntaryContextSw"
+style = "BrightRed"
+align = "Right"
+[[columns]]
 kind = "CpuTime"
 style = "BrightGreen"
 align = "Center"
